@@ -1,7 +1,3 @@
-import scipy
-import math
-
-import numpy as np
 
 from paramak import RotateMixedShape
 
@@ -12,33 +8,42 @@ class BlanketConstantThicknessArcH(RotateMixedShape):
     horizontally for the thickness of the blanket to back of the blanket.
 
     Arguments:
-        inner_mid_point (tuple of 2 floats): the x,z coordinates of the mid point
-            on the inner surface of the blanket.
+        inner_mid_point (tuple of 2 floats): the x,z coordinates of the mid
+            point on the inner surface of the blanket.
         inner_upper_point (tuple of 2 floats): the x,z coordinates of the upper
             point on the inner surface of the blanket.
-        inner_lower_point (tuple of 2 floats): the x,z coordinates of the lower point
-            on the inner surface of the blanket.
+        inner_lower_point (tuple of 2 floats): the x,z coordinates of the lower
+            point on the inner surface of the blanket.
         thickness (float): the radial thickness of the blanket in cm.
 
     Keyword Args:
-        name (str): the legend name used when exporting a html graph of the shape.
-        color (sequences of 3 or 4 floats each in the range 0-1): the color to use when
-            exportin as html graphs or png images.
-        material_tag (str): The material name to use when exporting the neutronics description.
-        stp_filename (str): The filename used when saving stp files as part of a reactor.
-        azimuth_placement_angle (float or iterable of floats): The angle or angles to use when
-            rotating the shape on the azimuthal axis.
-        rotation_angle (float): The rotation angle to use when revolving the solid (degrees).
-        workplane (str): The orientation of the CadQuery workplane. Options are XY, YZ or XZ.
-        intersect (CadQuery object): An optional CadQuery object to perform a boolean intersect with
-            this object.
-        cut (CadQuery object): An optional CadQuery object to perform a boolean cut with this object.
-        union (CadQuery object): An optional CadQuery object to perform a boolean union with this object.
+        name (str): the legend name used when exporting a html graph of the
+            shape.
+        color (sequences of 3 or 4 floats each in the range 0-1): the color to
+            use when exportin as html graphs or png images.
+        material_tag (str): The material name to use when exporting the
+            neutronics description.
+        stp_filename (str): The filename used when saving stp files as part of a
+            reactor.
+        azimuth_placement_angle (float or iterable of floats): The angle or
+            angles to use when rotating the shape on the azimuthal axis.
+        rotation_angle (float): The rotation angle to use when revolving the
+            solid (degrees).
+        workplane (str): The orientation of the CadQuery workplane. Options are
+            XY, YZ or XZ.
+        intersect (CadQuery object): An optional CadQuery object to perform a
+            boolean intersect with this object.
+        cut (CadQuery object): An optional CadQuery object to perform a boolean
+            cut with this object.
+        union (CadQuery object): An optional CadQuery object to perform a
+            boolean union with this object.
         tet_mesh (str): Insert description.
         physical_groups (type): Insert description.
 
     Returns:
-        a paramak shape object: A shape object that has generic functionality with points determined by the find_points() method. A CadQuery solid of the shape can be called via shape.solid.
+        a paramak shape object: A shape object that has generic functionality
+        with points determined by the find_points() method. A CadQuery solid of
+        the shape can be called via shape.solid.
     """
 
     def __init__(
@@ -89,8 +94,6 @@ class BlanketConstantThicknessArcH(RotateMixedShape):
         self.inner_mid_point = inner_mid_point
         self.thickness = thickness
 
-        self.find_points()
-
     def find_points(self):
 
         self.points = [
