@@ -1,7 +1,5 @@
-import math
-
 import numpy as np
-import scipy
+from scipy.interpolate import interp1d
 import sympy as sp
 
 from paramak import RotateMixedShape, diff_between_angles
@@ -11,10 +9,12 @@ class BlanketFP(RotateMixedShape):
     """A blanket volume created from plasma parameters.
 
     Args:
-        thickness (float, (float, float), callable): the thickness of the
-            blanket (cm). If float, constant thickness. If tuple of floats,
-            thickness will vary linearly between the two values. If callable,
-            thickness will be a function of poloidal angle (in degrees).
+        thickness (float or [float] or callable or [(float), (float)]):
+            the thickness of the blanket (cm). If float, constant thickness.
+            If tuple of floats, thickness will vary linearly between the two
+            values. If callable, thickness will be a function of poloidal
+            angle (in degrees). If a list of of two lists (thicknesses and
+            angles) then these will be used together with linear interpolation.
         start_angle (float): the angle in degrees to start the blanket,
             measured anti clockwise from 3 o'clock
         stop_angle (float): the angle in degrees to stop the blanket, measured
@@ -31,17 +31,24 @@ class BlanketFP(RotateMixedShape):
             Defaults to 2.0.
         vertical_displacement (float, optional): the vertical_displacement of
             the plasma (cm). Defaults to 0.
-        offset_from_plasma (float, optional): the distance bettwen the plasma
-            and the blanket (cm). Defaults to 0.
+        offset_from_plasma (float or [float] or callable or [(float), (float)]):
+            the distance bettwen the plasma and the blanket (cm). If float,
+            constant offset. If list of floats, offset will vary linearly
+            between the values. If callable, offset will be a function of
+            poloidal angle (in degrees) Defaults to 0. If a list of of two lists
+            (offsets and angles) then these will be used together with linear
+            interpolation.
         num_points (int, optional): number of points that will describe the
             shape. Defaults to 50.
         Others: see paramak.RotateMixedShape() arguments.
 
     Keyword Args:
-        thickness (float, (float, float), callable): the thickness of the
-            blanket (cm). If float, constant thickness. If tuple of floats,
-            thickness will vary linearly between the two values. If callable,
-            thickness will be a function of poloidal angle (in degrees).
+        thickness (float or [float] or callable or [(float), (float)]):
+            the thickness of the blanket (cm). If float, constant thickness.
+            If tuple of floats, thickness will vary linearly between the two
+            values. If callable, thickness will be a function of poloidal
+            angle (in degrees). If a list of of two lists (thicknesses and
+            angles) then these will be used together with linear interpolation.
         start_angle (float): the angle in degrees to start the blanket,
             measured anti clockwise from 3 o'clock
         stop_angle (float): the angle in degrees to stop the blanket, measured
@@ -55,14 +62,21 @@ class BlanketFP(RotateMixedShape):
             Defaults to 2.0.
         vertical_displacement (float): the vertical_displacement of
             the plasma (cm).
-        offset_from_plasma (float): the distance bettwen the plasma
-            and the blanket (cm).
+        offset_from_plasma (float or [float] or callable or [(float), (float)]):
+            the distance bettwen the plasma and the blanket (cm). If float,
+            constant offset. If list of floats, offset will vary linearly
+            between the values. If callable, offset will be a function of
+            poloidal angle (in degrees) Defaults to 0. If a list of of two lists
+            (offsets and angles) then these will be used together with linear
+            interpolation.
         num_points (int): number of points that will describe the
             shape.
         Others: see paramak.RotateMixedShape() attributes.
 
     Returns:
-        a paramak shape object: A shape object that has generic functionality with points determined by the find_points() method. A CadQuery solid of the shape can be called via shape.solid.
+        a paramak shape object: A shape object that has generic functionality
+            with points determined by the find_points() method. A CadQuery
+            solid of the shape can be called via shape.solid.
     """
 
     def __init__(
@@ -129,19 +143,15 @@ class BlanketFP(RotateMixedShape):
             self.major_radius = major_radius
             self.triangularity = triangularity
             self.elongation = elongation
-            self.offset_from_plasma = 0
         else:  # if plasma object is given, use its parameters
             self.minor_radius = plasma.minor_radius
             self.major_radius = plasma.major_radius
             self.triangularity = plasma.triangularity
             self.elongation = plasma.elongation
-            self.offset_from_plasma = offset_from_plasma
+        self.offset_from_plasma = offset_from_plasma
         self.num_points = num_points
-        # self.points = points
         self.physical_groups = None
 
-        self.find_points()
-
     @property
     def physical_groups(self):
         self.create_physical_groups()
@@ -167,15 +177,56 @@ class BlanketFP(RotateMixedShape):
     def thickness(self, thickness):
         self._thickness = thickness
 
+    def make_callable(self, attribute):
+        """This function transforms an attribute (thickness or offset) into a
+        callable function of theta
+        """
+        # if the attribute is a list, create a interpolated object of the
+        # values
+        if isinstance(attribute, (tuple, list)):
+            if isinstance(attribute[0], (tuple, list)) and \
+                isinstance(attribute[1], (tuple, list)) and \
+                    len(attribute) == 2:
+                # attribute is a list of 2 lists
+                if len(attribute[0]) != len(attribute[1]):
+                    raise ValueError('The length of angles list must equal \
+                     the length of values list')
+                list_of_angles = np.array(attribute[0])
+                offset_values = attribute[1]
+            else:
+                # no list of angles is given
+                offset_values = attribute
+                list_of_angles = np.linspace(
+                    self.start_angle,
+                    self.stop_angle,
+                    len(offset_values),
+                    endpoint=True)
+            interpolated_values = interp1d(list_of_angles, offset_values)
+
+        def fun(theta):
+            if callable(attribute):
+                return attribute(theta)
+            elif isinstance(attribute, (tuple, list)):
+                return interpolated_values(theta)
+            else:
+                return attribute
+        return fun
+
     def find_points(self):
         conversion_factor = 2 * np.pi / 360
 
         def R(theta, pkg=np):
+            """R(theta) plasma profile, theta being the angle in degree
+            """
+            theta *= conversion_factor
             return self.major_radius + self.minor_radius * pkg.cos(
                 theta + self.triangularity * pkg.sin(theta)
             )
 
         def Z(theta, pkg=np):
+            """R(theta) plasma profile, theta being the angle in degree
+            """
+            theta *= conversion_factor
             return (
                 self.elongation * self.minor_radius * pkg.sin(theta)
                 + self.vertical_displacement
@@ -183,53 +234,29 @@ class BlanketFP(RotateMixedShape):
 
         # create array of angles theta
         thetas = np.linspace(
-            self.start_angle * conversion_factor,
-            self.stop_angle * conversion_factor,
+            self.start_angle,
+            self.stop_angle,
             num=self.num_points,
             endpoint=True,
         )
 
         # create inner points
-        if self.plasma is None:
-            # if no plasma object is given simply use the equation
-            inner_points_R = R(thetas)
-            inner_points_Z = Z(thetas)
-
-            inner_points = [
-                [inner_points_R[i], inner_points_Z[i], "spline"]
-                for i in range(len(thetas))
-            ]
-        else:
-            # if a plasma is given
-            inner_points = self.create_offset_points(
-                thetas, R, Z, self.offset_from_plasma
-            )
+        inner_offset = self.make_callable(self.offset_from_plasma)
+        inner_points = self.create_offset_points(
+            thetas, R, Z, inner_offset
+        )
         inner_points[-1][2] = "straight"
 
-        # compute outer points
-        def new_offset(theta):
-            if callable(self.thickness):
-                # use the function of angle
-                return (
-                    self.thickness(
-                        theta /
-                        conversion_factor) +
-                    self.offset_from_plasma)
-            elif isinstance(self.thickness, tuple):
-                # increase thickness linearly
-                start_thickness, stop_thickness = self.thickness
-                a = (stop_thickness - start_thickness) / (
-                    self.stop_angle * conversion_factor
-                    - self.start_angle * conversion_factor
-                )
-                b = start_thickness - self.start_angle * a
-                return a * theta + b + self.offset_from_plasma
-            else:
-                # use the constant value
-                return self.thickness + self.offset_from_plasma
+        # create outer points
+        thickness = self.make_callable(self.thickness)
+
+        def outer_offset(theta):
+            return inner_offset(theta) + thickness(theta)
 
         outer_points = self.create_offset_points(
-            np.flip(thetas), R, Z, new_offset)
+            np.flip(thetas), R, Z, outer_offset)
+
+        # assemble
         points = inner_points + outer_points
         points[-1][2] = "straight"
         self.points = points
@@ -246,7 +273,7 @@ class BlanketFP(RotateMixedShape):
         :type Z_fun: callable
         :param offset: offset value (cm). offset=0 will follow the parametric
          equations.
-        :type offset: float, callable
+        :type offset: callable
         :return: list of points [[R1, Z1, connection1], [R2, Z2, connection2],
             ...]
         :rtype: list
@@ -261,12 +288,6 @@ class BlanketFP(RotateMixedShape):
         Z_derivative = sp.diff(Z_sp, theta_sp)
         points = []
 
-        def new_offset(theta):
-            if callable(offset):
-                return offset(theta)
-            else:
-                return offset
-
         for theta in thetas:
             # get local value of derivatives
             val_R_derivative = float(R_derivative.subs("theta", theta))
@@ -282,8 +303,8 @@ class BlanketFP(RotateMixedShape):
             ny /= normal_vector_norm
 
             # calculate outer points
-            val_R_outer = R_fun(theta) + new_offset(theta) * nx
-            val_Z_outer = Z_fun(theta) + new_offset(theta) * ny
+            val_R_outer = R_fun(theta) + offset(theta) * nx
+            val_Z_outer = Z_fun(theta) + offset(theta) * ny
 
             points.append([float(val_R_outer), float(val_Z_outer), "spline"])
         return points
