@@ -3,9 +3,10 @@ from paramak import Plasma
 
 
 class CenterColumnShieldPlasmaHyperbola(RotateMixedShape):
-    """A center column shield volume with a curvature controlled by the shape of the
-    plasma and offsets specified at the plasma center and edges. Shield thickness is
-    controlled by the relative values of the shield offsets and inner radius.
+    """A center column shield volume with a curvature controlled by the shape of
+    the plasma and offsets specified at the plasma center and edges. Shield
+    thickness is controlled by the relative values of the shield offsets and
+    inner radius.
 
     Args:
         major_radius (float): the major radius of the plasma.
@@ -13,29 +14,39 @@ class CenterColumnShieldPlasmaHyperbola(RotateMixedShape):
         triangulation (float): the triangularity of the plasma.
         elongation (float): the elongation of the plasma.
         inner_radius (float): the inner radius of the center column shield.
-        mid_offset (float): the offset of the shield from the plasma at the plasma center.
-        edge_offset (float): the offset of the shield from the plasma at the plasma edge.
+        mid_offset (float): the offset of the shield from the plasma at the
+            plasma center.
+        edge_offset (float): the offset of the shield from the plasma at the
+            plasma edge.
 
     Keyword Args:
-        name (str): the legend name used when exporting a html graph of the shape.
-        color (sequences of 3 or 4 floats each in the range 0-1): the color to use when
-            exportin as html graphs or png images.
-        material_tag (str): The material name to use when exporting the neutronics description.
-        stp_filename (str): The filename used when saving stp files as part of a reactor.
-        azimuth_placement_angle (float or iterable of floats): The angle or angles to use when
-            rotating the shape on the azimuthal axis.
-        rotation_angle (float): The rotation angle to use when revolving the solid (degrees).
-        workplane (str): The orientation of the CadQuery workplane. Options are XY, YZ or XZ.
-        intersect (CadQuery object): An optional CadQuery object to perform a boolean intersect with
-            this object.
-        cut (CadQuery object): An optional CadQuery object to perform a boolean cut with this object.
-        union (CadQuery object): An optional CadQuery object to perform a boolean union with this object.
+        name (str): the legend name used when exporting a html graph of the
+            shape.
+        color (sequences of 3 or 4 floats each in the range 0-1): the color to
+            use when exporting as html graphs or png images.
+        material_tag (str): The material name to use when exporting the
+            neutronics description.
+        stp_filename (str): The filename used when saving stp files as part of a
+            reactor.
+        azimuth_placement_angle (float or iterable of floats): The angle or
+            angles to use when rotating the shape on the azimuthal axis.
+        rotation_angle (float): The rotation angle to use when revolving the
+            solid (degrees).
+        workplane (str): The orientation of the CadQuery workplane. Options are
+            XY, YZ or XZ.
+        intersect (CadQuery object): An optional CadQuery object to perform a
+            boolean intersect with this object.
+        cut (CadQuery object): An optional CadQuery object to perform a boolean
+            cut with this object.
+        union (CadQuery object): An optional CadQuery object to perform a
+            boolean union with this object.
         tet_mesh (str): Insert description.
         physical_groups (type): Insert description.
 
     Returns:
-        a paramak shape object: A shape object that has generic functionality with points determined by
-            the find_points() method. A CadQuery solid of the shape can be called via shape.solid.
+        a paramak shape object: A shape object that has generic functionality
+        with points determined by the find_points() method. A CadQuery solid of
+        the shape can be called via shape.solid.
     """
 
     def __init__(
@@ -95,8 +106,6 @@ class CenterColumnShieldPlasmaHyperbola(RotateMixedShape):
         self.mid_offset = mid_offset
         self.edge_offset = edge_offset
 
-        self.find_points()
-
     @property
     def major_radius(self):
         return self._major_radius
