@@ -7,27 +7,37 @@ class PoloidalFieldCoil(RotateStraightShape):
     Args:
         height (float): the vertical (z axis) height of the coil (cm).
         width (float): the horizontal (x axis) width of the coil (cm).
-        center_point (tuple of floats): the center of the coil (x,z) values (cm).
+        center_point (tuple of floats): the center of the coil (x,z) values
+            (cm).
 
     Keyword Args:
-        name (str): the legend name used when exporting a html graph of the shape.
-        color (sequences of 3 or 4 floats each in the range 0-1): the color to use when
-            exportin as html graphs or png images.
-        material_tag (str): The material name to use when exporting the neutronics description.
-        stp_filename (str): The filename used when saving stp files as part of a reactor.
-        azimuth_placement_angle (float or iterable of floats): The angle or angles to use when
-            rotating the shape on the azimuthal axis.
-        rotation_angle (float): The rotation angle to use when revolving the solid (degrees).
-        workplane (str): The orientation of the CadQuery workplane. Options are XY, YZ or XZ.
-        intersect (CadQuery object): An optional CadQuery object to perform a boolean intersect with
-            this object.
-        cut (CadQuery object): An optional CadQuery object to perform a boolean cut with this object.
-        union (CadQuery object): An optional CadQuery object to perform a boolean union with this object.
+        name (str): the legend name used when exporting a html graph of the
+            shape.
+        color (sequences of 3 or 4 floats each in the range 0-1): the color to
+            use when exporting as html graphs or png images.
+        material_tag (str): The material name to use when exporting the
+            neutronics description.
+        stp_filename (str): The filename used when saving stp files as part of a
+            reactor.
+        azimuth_placement_angle (float or iterable of floats): The angle or
+            angles to use when rotating the shape on the azimuthal axis.
+        rotation_angle (float): The rotation angle to use when revolving the
+            solid (degrees).
+        workplane (str): The orientation of the CadQuery workplane. Options are
+            XY, YZ or XZ.
+        intersect (CadQuery object): An optional CadQuery object to perform a
+            boolean intersect with this object.
+        cut (CadQuery object): An optional CadQuery object to perform a boolean
+            cut with this object.
+        union (CadQuery object): An optional CadQuery object to perform a
+            boolean union with this object.
         tet_mesh (str): Insert description.
         physical_groups (type): Insert description.
 
     Returns:
-        a paramak shape object: A shape object that has generic functionality with points determined by the find_points() method. A CadQuery solid of the shape can be called via shape.solid.
+        a paramak shape object: A shape object that has generic functionality
+        with points determined by the find_points() method. A CadQuery solid of
+        the shape can be called via shape.solid.
     """
 
     def __init__(
@@ -76,8 +86,6 @@ class PoloidalFieldCoil(RotateStraightShape):
         self.height = height
         self.width = width
 
-        self.find_points()
-
     @property
     def center_point(self):
         return self._center_point
@@ -103,8 +111,8 @@ class PoloidalFieldCoil(RotateStraightShape):
         self._width = width
 
     def find_points(self):
-        """Finds the XZ points joined by straight connections that describe the 2D
-        profile of the poloidal field coil shape."""
+        """Finds the XZ points joined by straight connections that describe
+        the 2D profile of the poloidal field coil shape."""
 
         points = [
             (
@@ -122,7 +130,7 @@ class PoloidalFieldCoil(RotateStraightShape):
             (
                 self.center_point[0] - self.width / 2.0,
                 self.center_point[1] + self.height / 2.0,
-            ),  # upper left
+            )
         ]
 
         self.points = points
