@@ -1,3 +1,6 @@
+from collections import Iterable
+
+import cadquery as cq
 import numpy as np
 from scipy import integrate
 from scipy.optimize import minimize
@@ -16,6 +19,9 @@ class ToroidalFieldCoilPrincetonD(ExtrudeMixedShape):
         number_of_coils (int): the number of tf coils. This changes by the
             azimuth_placement_angle dividing up 360 degrees by the number of
             coils.
+        vertical_displacement (float, optional): vertical displacement (cm).
+            Defaults to 0.0.
+        with_inner_leg (Boolean): Include the inner tf leg (default True)
 
     Keyword Args:
         stp_filename (str, optional): The filename used when saving stp files
@@ -41,12 +47,14 @@ class ToroidalFieldCoilPrincetonD(ExtrudeMixedShape):
         thickness,
         distance,
         number_of_coils,
+        vertical_displacement=0.0,
         stp_filename="ToroidalFieldCoilPrincetonD.stp",
         stl_filename="ToroidalFieldCoilPrincetonD.stl",
         color=(0.5, 0.5, 0.5),
         azimuth_placement_angle=0,
         name=None,
         material_tag="outer_tf_coil_mat",
+        with_inner_leg=True,
         **kwargs
     ):
 
@@ -82,9 +90,17 @@ class ToroidalFieldCoilPrincetonD(ExtrudeMixedShape):
         self.thickness = thickness
         self.distance = distance
         self.number_of_coils = number_of_coils
+        self.vertical_displacement = vertical_displacement
+        self.with_inner_leg = with_inner_leg
 
-        self.find_points()
+    @property
+    def azimuth_placement_angle(self):
         self.find_azimuth_placement_angle()
+        return self._azimuth_placement_angle
+
+    @azimuth_placement_angle.setter
+    def azimuth_placement_angle(self, value):
+        self._azimuth_placement_angle = value
 
     def compute_inner_points(self, R1, R2):
         """Computes the inner curve points
@@ -142,7 +158,7 @@ class ToroidalFieldCoilPrincetonD(ExtrudeMixedShape):
         Returns:
             (list, list): R and Z lists for outer curve points
         """
-        new_R, new_Z = [], []
+        R_outer, Z_outer = [], []
         for i in range(len(derivative)):
             nx = -derivative[i]
             ny = 1
@@ -153,35 +169,58 @@ class ToroidalFieldCoilPrincetonD(ExtrudeMixedShape):
             # calculate outer points
             val_R_outer = R[i] + thickness * nx
             val_Z_outer = Z[i] + thickness * ny
-            new_R.append(val_R_outer)
-            new_Z.append(val_Z_outer)
-        new_R = np.concatenate([new_R, np.flip(np.array(new_R))])
-        new_Z = np.concatenate([new_Z, np.flip(-np.array(new_Z))])
-        return new_R, new_Z
+            R_outer.append(val_R_outer)
+            Z_outer.append(val_Z_outer)
+        R_outer = np.concatenate([R_outer, np.flip(np.array(R_outer))])
+        Z_outer = np.concatenate([Z_outer, np.flip(-np.array(Z_outer))])
+        return R_outer, Z_outer
 
     def find_points(self):
         """Finds the XZ points joined by connections that describe the 2D
         profile of the toroidal field coil shape."""
         # compute inner and outer points
-        R, Z, dz_dr = self.compute_inner_points(self.R1, self.R2)
-        R_, Z_ = self.compute_outer_points(R, Z, self.thickness, dz_dr)
+        R_inner, Z_inner, dz_dr = self.compute_inner_points(self.R1, self.R2)
+        R_outer, Z_outer = self.compute_outer_points(
+            R_inner, Z_inner, self.thickness, dz_dr)
+        R_outer, Z_outer = np.flip(R_outer), np.flip(Z_outer)
 
+        # add vertical displacement
+        Z_outer += self.vertical_displacement
+        Z_inner += self.vertical_displacement
+
+        # extract helping points for inner leg
+        inner_leg_connection_points = [
+            (R_inner[0], Z_inner[0]),
+            (R_inner[-1], Z_inner[-1]),
+            (R_outer[0], Z_outer[0]),
+            (R_outer[-1], Z_outer[-1])
+        ]
+        self.inner_leg_connection_points = inner_leg_connection_points
+
+        # add the leg to the points
+        if self.with_inner_leg:
+            R_inner = np.append(R_inner, R_inner[0])
+            Z_inner = np.append(Z_inner, Z_inner[0])
+
+            R_outer = np.append(R_outer, R_outer[0])
+            Z_outer = np.append(Z_outer, Z_outer[0])
         # add connections
-        inner_points = []
-        for r, z in zip(R, Z):
-            inner_points.append([r, z, 'spline'])
+        inner_points = [[r, z, 'spline'] for r, z in zip(R_inner, Z_inner)]
+        outer_points = [[r, z, 'spline'] for r, z in zip(R_outer, Z_outer)]
+        if self.with_inner_leg:
+            outer_points[-2][2] = 'straight'
+            inner_points[-2][2] = 'straight'
+
         inner_points[-1][2] = 'straight'
-        outer_points = []
-        for r, z in zip(np.flip(R_), np.flip(Z_)):
-            outer_points.append([r, z, 'spline'])
-        outer_points[-1][2] = "straight"
+        outer_points[-1][2] = 'straight'
 
         points = inner_points + outer_points
 
         self.points = points
 
     def find_azimuth_placement_angle(self):
-        """Calculates the azimuth placement angles based on the number of tf coils"""
+        """Calculates the azimuth placement angles based on the number of tf
+        coils"""
 
         angles = list(
             np.linspace(
