@@ -1,10 +1,8 @@
 from collections import Iterable
-from hashlib import blake2b
 
 import cadquery as cq
 
 from paramak import Shape
-from paramak.utils import cut_solid, intersect_solid, union_solid
 
 
 class ExtrudeMixedShape(Shape):
@@ -13,20 +11,25 @@ class ExtrudeMixedShape(Shape):
 
     Args:
         points (list of tuples each containing X (float), Z (float), connection (str)):
-            a list of XZ coordinates and connection types. The connection types are
-            either 'straight', 'spline' or 'circle'. For example [(2.,1.,'straight'),
-            (2.,2.,'straight'), (1.,2.,'spline'), (1.,1.,'spline'), (2.,1.,'spline')].
-        stp_filename (str): the filename used when saving stp files as part of a reactor
+            a list of XZ coordinates and connection types. The connection types
+            are either 'straight', 'spline' or 'circle'. For example [(2., 1.,
+            'straight'), (2.,2.,'straight'), (1.,2.,'spline'), (1.,1.,'spline'),
+            (2.,1.,'spline')].
+        stp_filename (str): the filename used when saving stp files as part of a
+            reactor
         color (RGB or RGBA - sequences of 3 or 4 floats, respectively, each in the range 0-1):
             the color to use when exporting as html graphs or png images
         distance (float): the extrusion distance to use (cm units if used for neutronics)
-        azimuth_placement_angle (float or iterable of floats): the angle or angles to use when
-            rotating the shape on the azimuthal axis
-        cut (CadQuery object): an optional CadQuery object to perform a boolean cut with
-            this object
-        material_tag (str): the material name to use when exporting the neutronics descrption
-        name (str): the legend name used when exporting a html graph of the shape
-        workplane (str): the orientation of the CadQuery workplane. Options are XY, YZ, XZ.
+        azimuth_placement_angle (float or iterable of floats): the angle or
+            angles to use when rotating the shape on the azimuthal axis
+        cut (CadQuery object): an optional CadQuery object to perform a boolean
+            cut with this object
+        material_tag (str): the material name to use when exporting the
+            neutronics descrption
+        name (str): the legend name used when exporting a html graph of the
+            shape
+        workplane (str): the orientation of the CadQuery workplane. Options are
+            XY, YZ, XZ.
 
     Returns:
         a paramak shape object: a Shape object that has generic functionality
@@ -67,49 +70,15 @@ class ExtrudeMixedShape(Shape):
             stl_filename=stl_filename,
             azimuth_placement_angle=azimuth_placement_angle,
             workplane=workplane,
+            cut=cut,
+            intersect=intersect,
+            union=union,
             **default_dict
         )
 
-        self.cut = cut
-        self.intersect = intersect
-        self.union = union
         self.distance = distance
         self.solid = solid
 
-    @property
-    def cut(self):
-        return self._cut
-
-    @cut.setter
-    def cut(self, value):
-        self._cut = value
-
-    @property
-    def intersect(self):
-        return self._intersect
-
-    @intersect.setter
-    def intersect(self, value):
-        self._intersect = value
-
-    @property
-    def union(self):
-        return self._union
-
-    @union.setter
-    def union(self, value):
-        self._union = value
-
-    @property
-    def solid(self):
-        if self.get_hash() != self.hash_value:
-            self.create_solid()
-        return self._solid
-
-    @solid.setter
-    def solid(self, value):
-        self._solid = value
-
     @property
     def distance(self):
         return self._distance
@@ -126,8 +95,6 @@ class ExtrudeMixedShape(Shape):
         :rtype: a cadquery solid
         """
 
-        # print('create_solid() has been called')
-
         # obtains the first two values of the points list
         XZ_points = [(p[0], p[1]) for p in self.points]
 
@@ -185,23 +152,8 @@ class ExtrudeMixedShape(Shape):
         else:
             # Peform rotations for a single azimuth_placement_angle angle
             solid = solid.rotate(
-                (0, 0, 1), (0, 0, -1), self.azimuth_placement_angle)
+                (0, 0, -1), (0, 0, 1), self.azimuth_placement_angle)
 
-        # If a cut solid is provided then perform a boolean cut
-        if self.cut is not None:
-            solid = cut_solid(solid, self.cut)
-
-        # If an intersect is provided then perform a boolean intersect
-        if self.intersect is not None:
-            solid = intersect_solid(solid, self.intersect)
-
-        # If an intersect is provided then perform a boolean intersect
-        if self.union is not None:
-            solid = union_solid(solid, self.union)
-
-        self.solid = solid
-
-        # Calculate hash value for current solid
-        self.hash_value = self.get_hash()
+        self.perform_boolean_operations(solid)
 
         return solid
