@@ -1,31 +1,35 @@
-import math
+
 from collections import Iterable
-from hashlib import blake2b
 
 import cadquery as cq
 
 from paramak import Shape
-from paramak.utils import cut_solid, intersect_solid, union_solid
 
 
 class ExtrudeStraightShape(Shape):
     """Extrudes a 3d CadQuery solid from points connected with straight lines
 
     Args:
-        points (a list of tuples each containing X (float), Z (float)): a list of
-            XZ coordinates connected by straight connections. For example [(2.,1.),
-            (2.,2.), (1.,2.), (1.,1.), (2.,1.)]
-        stp_filename (str): the filename used when saving stp files as part of a reactor
+        points (a list of tuples each containing X (float), Z (float)): a list
+            of XZ coordinates connected by straight connections. For example
+            [(2.,1.), (2.,2.), (1.,2.), (1.,1.), (2.,1.)]
+        stp_filename (str): the filename used when saving stp files as part of a
+            reactor
         color (RGB or RGBA - sequences of 3 or 4 floats, respectively, each in the range 0-1):
             the color to use when exporting as html graphs or png images
         distance (float): the extrusion distance to use (cm units if used for neutronics)
-        azimuth_placement_angle (float or iterable of floats): the angle or angles to use when
-            rotating the shape on the azimuthal axis
-        cut (CadQuery object): an optional CadQuery object to perform a boolean cut with
-            this object
-        material_tag (str): the material name to use when exporting the neutronics descrption
-        name (str): the legend name used when exporting a html graph of the shape
-        workplane (str): the orientation of the CadQuery workplane. Options are XY, YZ, XZ.
+        extrude_both (bool): if set to True, the extrusion will occur in both
+            directions. Defaults to True.
+        azimuth_placement_angle (float or iterable of floats): the angle or
+            angles to use when rotating the shape on the azimuthal axis
+        cut (CadQuery object): an optional CadQuery object to perform a boolean
+            cut with this object
+        material_tag (str): the material name to use when exporting the
+            neutronics descrption
+        name (str): the legend name used when exporting a html graph of the
+            shape
+        workplane (str): the orientation of the CadQuery workplane. Options are
+            XY, YZ, XZ.
 
     Returns:
         a paramak shape object: a Shape object that has generic functionality
@@ -35,6 +39,7 @@ class ExtrudeStraightShape(Shape):
         self,
         points,
         distance,
+        extrude_both=True,
         workplane="XZ",
         stp_filename="ExtrudeStraightShape.stp",
         stl_filename="ExtrudeStraightShape.stl",
@@ -66,48 +71,15 @@ class ExtrudeStraightShape(Shape):
             stl_filename=stl_filename,
             azimuth_placement_angle=azimuth_placement_angle,
             workplane=workplane,
+            cut=cut,
+            intersect=intersect,
+            union=union,
             **default_dict
         )
 
-        self.cut = cut
-        self.intersect = intersect
-        self.union = union
         self.distance = distance
         self.solid = solid
-
-    @property
-    def cut(self):
-        return self._cut
-
-    @cut.setter
-    def cut(self, cut):
-        self._cut = cut
-
-    @property
-    def intersect(self):
-        return self._intersect
-
-    @intersect.setter
-    def intersect(self, value):
-        self._intersect = value
-
-    @property
-    def union(self):
-        return self._union
-
-    @union.setter
-    def union(self, value):
-        self._union = value
-
-    @property
-    def solid(self):
-        if self.get_hash() != self.hash_value:
-            self.create_solid()
-        return self._solid
-
-    @solid.setter
-    def solid(self, solid):
-        self._solid = solid
+        self.extrude_both = extrude_both
 
     @property
     def distance(self):
@@ -125,14 +97,12 @@ class ExtrudeStraightShape(Shape):
            A CadQuery solid: A 3D solid volume
         """
 
-        # print('create_solid() has been called')
-
         # Creates a cadquery solid from points and revolves
         solid = (
             cq.Workplane(self.workplane)
             .polyline(self.points)
             .close()
-            .extrude(distance=-self.distance / 2.0, both=True)
+            .extrude(distance=-self.distance / 2.0, both=self.extrude_both)
         )
 
         # Checks if the azimuth_placement_angle is a list of angles
@@ -151,23 +121,8 @@ class ExtrudeStraightShape(Shape):
         else:
             # Peform rotations for a single azimuth_placement_angle angle
             solid = solid.rotate(
-                (0, 0, 1), (0, 0, -1), self.azimuth_placement_angle)
+                (0, 0, -1), (0, 0, 1), self.azimuth_placement_angle)
 
-        # If a cut solid is provided then perform a boolean cut
-        if self.cut is not None:
-            solid = cut_solid(solid, self.cut)
-
-        # If an intersect is provided then perform a boolean intersect
-        if self.intersect is not None:
-            solid = intersect_solid(solid, self.intersect)
-
-        # If an intersect is provided then perform a boolean intersect
-        if self.union is not None:
-            solid = union_solid(solid, self.union)
-
-        self.solid = solid
-
-        # Calculate hash value for current solid
-        self.hash_value = self.get_hash()
+        self.perform_boolean_operations(solid)
 
         return solid
