@@ -1,4 +1,3 @@
-
 import os
 import json
 import unittest
@@ -35,7 +34,7 @@ class test_object_properties(unittest.TestCase):
             os.system("rm " + output_filename)
         os.system("python make_collarge.py")
         for output_filename in output_filenames:
-            assert Path(output_filename).exists() == True
+            assert Path(output_filename).exists()
             os.system("rm " + output_filename)
 
     def test_make_paramak_animation(self):
@@ -56,7 +55,7 @@ class test_object_properties(unittest.TestCase):
             os.system("rm " + output_filename)
         os.system("python make_animation.py -n 3")
         for output_filename in output_filenames:
-            assert Path(output_filename).exists() == True
+            assert Path(output_filename).exists()
             os.system("rm " + output_filename)
 
     def test_RotateStraightShape_export_3d_image(self):
@@ -83,8 +82,9 @@ class test_object_properties(unittest.TestCase):
         os.system("python make_simple_neutronics_model.py")
         with open(output_filename) as json_file:
             data = json.load(json_file)
-        assert data['TBR'] == pytest.approx(0.456, abs=0.01)
+        assert data["TBR"] == pytest.approx(0.456, abs=0.01)
         os.system("rm " + output_filename)
 
+
 if __name__ == "__main__":
     unittest.main()
