@@ -39,10 +39,7 @@ class test_object_properties(unittest.TestCase):
             "firstwall.stp",
             "Graveyard.stp",
             "inboard_tf_coils.stp",
-            "pf_coil_0.stp",
-            "pf_coil_1.stp",
-            "pf_coil_2.stp",
-            "pf_coil_3.stp",
+            "pf_coils.stp",
             "plasma.stp",
             "tf_coil.stp"
         ]
@@ -67,15 +64,12 @@ class test_object_properties(unittest.TestCase):
             'blanket.stp',
             'outboard_rear_blanket_wall.stp',
             'outboard_tf_coil.stp',
-            'pf_coil_0.stp',
-            'pf_coil_1.stp',
-            'pf_coil_2.stp',
-            'pf_coil_3.stp',
+            'pf_coils.stp',
             'Graveyard.stp'
         ]
         for output_filename in output_filenames:
             os.system("rm " + output_filename)
-        os.system("python make_parametric_single_null_submersion_ball_reactor.py")
+        os.system("python make_parametric_single_null_submersion_reactor.py")
         for output_filename in output_filenames:
             assert Path(output_filename).exists() is True
             os.system("rm " + output_filename)
@@ -124,25 +118,38 @@ class test_object_properties(unittest.TestCase):
         os.chdir(Path(cwd))
         os.chdir(Path("examples/example_parametric_components"))
         output_filenames = [
-            "blanket_constant_thickness_outboard_plasma.stp",
-            "blanket_constant_thickness_inboard_plasma.stp",
-            "blanket_constant_thickness_plasma.stp",
-            "center_column_shield_cylinder.stp",
-            "center_column_shield_hyperbola.stp",
-            "center_column_shield_flat_top_hyperbola.stp",
-            "center_column_shield_plasma_hyperbola.stp",
-            "poloidal_field_coil.stp",
-            "poloidal_field_coil_case_fc.stp",
-            "poloidal_field_coil_case.stp",
-            "inner_tf_coils_circular.stp",
-            "inner_tf_coils_flat.stp",
-            "blanket_arc_v.stp",
-            "blanket_arc_h.stp",
-            "tf_coil_rectangle.stp",
-            "toroidal_field_coil_coat_hanger.stp",
-            "toroidal_field_coil_triple_arc.stp",
-            "toroidal_field_coil_princeton_d.stp"
-        ]
+            'plasma_shape.stp',
+            'blanket_constant_thickness_outboard_plasma.stp',
+            'blanket_constant_thickness_inboard_plasma.stp',
+            'blanket_constant_thickness_plasma.stp',
+            'center_column_shield_cylinder.stp',
+            'firstwall_from_center_column_shield_cylinder.stp',
+            'center_column_shield_hyperbola.stp',
+            'firstwall_from_center_column_shield_hyperbola.stp',
+            'center_column_shield_circular.stp',
+            'firstwall_from_center_column_shield_circular.stp',
+            'center_column_shield_flat_top_hyperbola.stp',
+            'firstwall_from_center_column_shield_flat_top_hyperbola.stp',
+            'center_column_shield_flat_top_Circular.stp',
+            'firstwall_from_center_column_shield_flat_top_Circular.stp',
+            'center_column_shield_plasma_hyperbola.stp',
+            'firstwall_from_center_column_shield_plasma_hyperbola.stp',
+            'inner_tf_coils_circular.stp',
+            'inner_tf_coils_flat.stp',
+            'pf_coil_case_set.stp',
+            'pf_coil_set.stp',
+            'pf_coil_cases_set.stp',
+            'poloidal_field_coil.stp',
+            'pf_coil_cases_set_fc.stp',
+            'poloidal_field_coil_case_fc.stp',
+            'poloidal_field_coil_case.stp',
+            'blanket_arc_v.stp',
+            'blanket_arc_h.stp',
+            'tf_coil_rectangle.stp',
+            'toroidal_field_coil_coat_hanger.stp',
+            'toroidal_field_coil_triple_arc.stp',
+            'toroidal_field_coil_princeton_d.stp',
+            'ITER_type_divertor.stp']
         for output_filename in output_filenames:
             os.system("rm " + output_filename)
         os.system("python make_all_parametric_components.py")
@@ -218,16 +225,26 @@ class test_object_properties(unittest.TestCase):
             assert Path(output_filename).exists() is True
             os.system("rm " + output_filename)
 
-    def test_make_demo_style_segmented_blanket(self):
+    def test_make_demo_style_blanket(self):
         """Runs the example and checks the output files are produced"""
         os.chdir(Path(cwd))
         os.chdir(Path("examples/example_parametric_components"))
-        output_filename = "segmented_blanket.stp"
+        output_filename = "blanket.stp"
         os.system("rm " + output_filename)
         os.system("python make_demo_style_blankets.py")
         assert Path(output_filename).exists() is True
         os.system("rm " + output_filename)
 
+    def test_make_segmented_firstwall(self):
+        """Runs the example and checks the output files are produced"""
+        os.chdir(Path(cwd))
+        os.chdir(Path("examples/example_parametric_components"))
+        output_filename = "segmented_firstwall.stp"
+        os.system("rm " + output_filename)
+        os.system("python make_firstwall_for_neutron_wall_loading.py")
+        assert Path(output_filename).exists() is True
+        os.system("rm " + output_filename)
+
 
 if __name__ == "__main__":
     unittest.main()
